@@ -3,30 +3,29 @@
 #' Functions to manage the list of known servers to which
 #' \pkg{rsconnect} can deploy and manage applications.
 #'
-#' Register a server with \code{addServer} or \code{discoverServers} (the latter
+#' Register a server with `addServer` or `discoverServers` (the latter
 #' is useful only if your administrator has configured server autodiscovery).
 #' Once a server is registered, you can connect to an account on the server
-#' using \code{\link{connectUser}}.
+#' using [connectUser()].
 #'
-#' The \code{servers} and \code{serverInfo} functions are provided for viewing
+#' The `servers` and `serverInfo` functions are provided for viewing
 #' previously registered servers.
 #'
-#' There is always at least one server registered (the \code{shinyapps.io}
-#' server)
+#' Servers for `shinyapps.io` and `rstudio.cloud` are always registered.
 #'
 #' @param name Optional nickname for the server. If none is given, the nickname
 #'   is inferred from the server's hostname.
-#' @param url Server's URL. Should look like \code{http://servername/} or
-#'  \code{http://servername:port/}.
-#' @param local Return only local servers (i.e. not \code{shinyapps.io})
+#' @param url Server's URL. Should look like `http://servername/` or
+#'  `http://servername:port/`.
+#' @param local Return only local servers (i.e. not `shinyapps.io`)
 #' @param certificate Optional; a path a certificate file to be used when making
 #'   SSL connections to the server. The file's contents are copied and stored by
 #'   the \pkg{rsconnect} package. Can also be a character vector containing the
 #'   certificate's contents.
 #' @param quiet Suppress output and prompts where possible.
 #' @return
-#' \code{servers} returns a data frame with registered server names and URLs.
-#' \code{serverInfo} returns a list with details for a particular server.
+#' `servers` returns a data frame with registered server names and URLs.
+#' `serverInfo` returns a list with details for a particular server.
 #' @rdname servers
 #' @examples
 #' \dontrun{
@@ -63,7 +62,10 @@ servers <- function(local = FALSE) {
   if (local) {
     locals
   } else {
-    rbind(locals, as.data.frame(shinyappsServerInfo(), stringsAsFactors = FALSE))
+    rbind(
+      locals,
+      as.data.frame(shinyappsServerInfo(), stringsAsFactors = FALSE),
+      as.data.frame(cloudServerInfo(), stringsAsFactors = FALSE))
   }
 }
 
@@ -84,6 +86,14 @@ shinyappsServerInfo <- function() {
                                "https://api.shinyapps.io/v1"))
 }
 
+cloudServerInfo <- function() {
+  info <- list(name = "rstudio.cloud",
+               certificate = inferCertificateContents(
+                 system.file("cert/shinyapps.io.pem", package = "rsconnect")),
+               url = getOption("rsconnect.shinyapps_url",
+                               "https://api.shinyapps.io/v1"))
+}
+
 #' @rdname servers
 #' @export
 discoverServers <- function(quiet = FALSE) {
@@ -218,6 +228,11 @@ serverInfo <- function(name) {
     return(shinyappsServerInfo())
   }
 
+  # there's no config file for rstudio.cloud
+  if (identical(name, "rstudio.cloud")) {
+    return(cloudServerInfo())
+  }
+
   configFile <- serverConfigFile(name)
   if (!file.exists(configFile))
     stop(missingServerErrorMessage(name))
@@ -254,22 +269,15 @@ missingServerErrorMessage <- function(name) {
 }
 
 clientForAccount <- function(account) {
-  authInfo <- account
 
   # determine appropriate server information for account
-  if (account$server == shinyappsServerInfo()$name) {
-    serverInfo <- shinyappsServerInfo()
-    constructor <- lucidClient
+  if (isCloudServer(account$server)) {
+    constructor <- lucidClientForAccount(account)
   } else {
     serverInfo <- serverInfo(account$server)
-    constructor <- connectClient
+    account$certificate <- serverInfo$certificate
+    connectClient(serverInfo$url, account)
   }
-
-  # promote certificate into auth info
-  authInfo$certificate <- serverInfo$certificate
-
-  # invoke client constructor
-  constructor(serverInfo$url, authInfo)
 }
 
 ensureConnectServerUrl <- function(url) {
